import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl ='https://gist.githubusercontent.com/Sai-Bhavana-Akkineni/aae27b5591bd9dea6af9c9d6cf57459d/raw/e06747407727b208b89a121e1faee8db9b4ac2b0/ICE6_Bhavana'
const width = 850;
const height = 500;
const margin = { top: 20, right: 20, bottom: 35, left: 140 };



const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.match = +d['2018'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 11));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.Sports))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.match)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="green" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".72em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".30em"
            y={yScale(tickValue) + yScale.bandwidth() / 3}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Sports}
            x={0}
            y={yScale(d.Sports)}
            width={xScale(d.match)}
            height={yScale.bandwidth()}
            fill="orange"
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);